@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -48,38 +48,37 @@
  */
 package com.openexchange.groupware.settings.extensions.osgi;
 
-import com.openexchange.groupware.settings.extensions.ServicePublisher;
-import org.osgi.framework.ServiceRegistration;
-import org.osgi.framework.BundleContext;
-
-import java.util.Map;
 import java.util.HashMap;
+import java.util.Map;
+import org.osgi.framework.BundleContext;
+import org.osgi.framework.ServiceRegistration;
+import com.openexchange.groupware.settings.extensions.ServicePublisher;
 
 /**
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 public class OSGiServicePublisher implements ServicePublisher {
 
-    private Map<Object, ServiceRegistration> serviceRegistrations = new HashMap<Object, ServiceRegistration>();
+    private final Map<Object, ServiceRegistration> serviceRegistrations = new HashMap<Object, ServiceRegistration>();
     private BundleContext context = null;
 
-    public OSGiServicePublisher(BundleContext context) {
+    public OSGiServicePublisher(final BundleContext context) {
         this.context = context;
     }
 
-    public void publishService(Class<?> clazz, Object service) {
-        ServiceRegistration registration = context.registerService(clazz.getName(), service, null);
+    public void publishService(final Class<?> clazz, final Object service) {
+        final ServiceRegistration registration = context.registerService(clazz.getName(), service, null);
         serviceRegistrations.put(service, registration);
     }
 
-    public void removeService(Class<?> clazz, Object service) {
-        ServiceRegistration registration = serviceRegistrations.get(service);
+    public void removeService(final Class<?> clazz, final Object service) {
+        final ServiceRegistration registration = serviceRegistrations.get(service);
         serviceRegistrations.remove(service);
         registration.unregister();
     }
 
     public void removeAllServices() {
-        for(ServiceRegistration registration : serviceRegistrations.values()) {
+        for(final ServiceRegistration registration : serviceRegistrations.values()) {
             registration.unregister();
         }
         serviceRegistrations.clear();
